function [ y1,y2 ] = ini_distr( lx,d1,d2,delta1,delta2,n,ratio )
%INI_DISTR produces the intial distribution of Y1 and Y2 based on the distance, number and ratio;
%Output:y1,y2-the spatial distribution of Y1 and Y2(matrix);
%Input:
%lx is the total size in um
%d1 is the distance of Y1 from the edge of the bacterial band from the source side
%d2 is the distance of Y1 from the edge of the bacterial band from the source side
%delta11 is the width of the Y1 band region
%delta12 is the width of the Y2 band region
%n is the total number of Y1+Y2;
%ratio = Y1:Y2

ny1 = 2*ratio*n/(ratio+1);
ny2 = 2*n/(ratio+1);
distance = meshgrid(1:lx);
distance = distance.^2 + distance'.^2;
distance = sqrt(distance);
    
y1 = zeros(lx);
y2 = zeros(lx);

y1(distance<d1 & distance>=d1-delta1) = 1;
y2(distance<d2 & distance>=d2-delta2) = 1;

y12 = fliplr(y1);
y22 = flipud(y12);
y21 = flipud(y1);
y1 = [y1,y12;y21,y22];

y12 = fliplr(y2);
y22 = flipud(y12);
y21 = flipud(y2);
y2 = [y2,y12;y21,y22];

sum1 = sum(sum(y1(2:end-1,2:end-1)));
sum2 = sum(sum(y2(2:end-1,2:end-1)));

y1 = y1.*ny1./sum1;
y2 = y2.*ny2./sum2;

end

